// Base layout
import Layout from "./components/Layout"

// i18n
import useTranslation from 'next-translate/useTranslation'

// React Router
import { useRouter } from 'next/router'

// next-seo
import { NextSeo } from 'next-seo';

export default function Server(props) {
  const router = useRouter()
  const { locale, locales, defaultLocale, pathname } = router
  const { t, lang } = useTranslation("server")

  return (
    <>
      <NextSeo
        title="yude.jp サーバー上"
        description="yude.jp 上に設置されているサーバーの一覧、情報"
      />
      <Layout title={t('status')}>
          <div className="my-9 text-center">
          
          {
           // Header
          }
          <div className="mb-5">
            <p className="text-left text-4xl">{t('status')} <p className="md:inline font-mono text-base sm:">Powered / Generated by Mackerel.</p></p>
          </div>
          
          {
              // yui
          }
          <h2 className="text-2xl text-left font-bold leading-7 sm:text-3xl sm:truncate">yui</h2>
          <div className="flex xl:w-2/3 text-center">
          <div className="flex-1"><p className="font-bold">CPU </p>i7-2600</div>
          <div className="flex-1"><p className="font-bold">RAM </p>DDR3 24GB</div>
          <div className="flex-1"><p className="font-bold">OS </p>Arch Linux</div>
          <div className="flex-1"><p className="font-bold">{t('location')} </p>{t('hiroshima')}</div>
          </div>
          <iframe className="w-full h-96" src="https://mackerel.io/embed/public/embed/heHnGhDanoIDlf7jjxUe9yPVrsG3deeH5ptD8suErrq5w46crWEIYdLfzLoukzfF?period=24h" height="400" frameBorder="0" scrolling="no"></iframe>
          
          {
              // saika
          }
          <h2 className="text-2xl text-left font-bold leading-7 sm:text-3xl sm:truncate">saika</h2>
          <div className="flex xl:w-2/3 text-center">
          <div className="flex-1"><p className="font-bold">CPU </p>i5-6500</div>
          <div className="flex-1"><p className="font-bold">RAM </p>DDR4 8GB</div>
          <div className="flex-1"><p className="font-bold">OS </p>Ubuntu Server 20.04.3 LTS</div>
          <div className="flex-1"><p className="font-bold">{t('location')} </p>{t('hiroshima')}</div>
          </div>
          <iframe className="w-full h-96" src="https://mackerel.io/embed/public/embed/QCRK3wZxG7ufgunJ5iuIs9cIEJ490swAmlYMF50nNLmJw6gASXyVlzhrybiE2A1G?period=24h" height="400" frameBorder="0" scrolling="no"></iframe>
          
          {
              // yukino
          }
          <h2 className="text-2xl text-left font-bold leading-7 sm:text-3xl sm:truncate">yukino</h2>
          <div className="flex xl:w-2/3 text-center">
          <div className="flex-1"><p className="font-bold">{t('model')} </p>Raspberry Pi 4 Model B Rev 1.2</div>
          <div className="flex-1"><p className="font-bold">RAM </p>4GB</div>
          <div className="flex-1"><p className="font-bold">OS </p>Raspbian GNU/Linux 10 (buster)</div>
          <div className="flex-1"><p className="font-bold">{t('location')} </p>{t('tottori')}</div>
          </div>
          <iframe className="w-full h-96" src="https://mackerel.io/embed/public/embed/5HVbQiwuxrMithyrGjmmQCCOVgJ6Ptf94SDA2qWSTsh2rtz7pjePihYzaW5QEml4?period=24h" height="400" frameBorder="0" scrolling="no"></iframe>
          
          {
              // iroha
          }
          <h2 className="text-2xl text-left font-bold leading-7 sm:text-3xl sm:truncate">iroha</h2>
          <div className="flex xl:w-2/3 text-center">
          <div className="flex-1"><p className="font-bold">{t('service')} </p>Oracle Cloud</div>
          <div className="flex-1"><p className="font-bold">{t('shape')} </p>VM.Standard.E2.1.Micro</div>
          <div className="flex-1"><p className="font-bold">RAM </p>1GB</div>
          <div className="flex-1"><p className="font-bold">OS </p>Ubuntu 20.04 LTS</div>
          <div className="flex-1"><p className="font-bold">{t('region')} </p>Japan Central (Osaka)</div>
          </div>
          <iframe className="w-full h-96" src="https://mackerel.io/embed/public/embed/wgmTz7aTgvwfyU6qVHrJJmQlpOHCUJK6qw0W9sJTX68WOI8TFtc27YvJ7dwkQEGv?period=24h" height="400" frameBorder="0" scrolling="no"></iframe>
          
          
          {
              // komachi
          }
          <h2 className="text-2xl text-left font-bold leading-7 sm:text-3xl sm:truncate">komachi</h2>
          <div className="flex xl:w-2/3 text-center">
          <div className="flex-1"><p className="font-bold">{t('service')} </p>Oracle Cloud</div>
          <div className="flex-1"><p className="font-bold">{t('shape')} </p>VM.Standard.E2.1.Micro</div>
          <div className="flex-1"><p className="font-bold">RAM </p>1GB</div>
          <div className="flex-1"><p className="font-bold">OS </p>Ubuntu 20.04 LTS</div>
          <div className="flex-1"><p className="font-bold">{t('region')} </p>Japan Central (Osaka)</div>
          </div>
          <iframe className="w-full h-96" src="https://mackerel.io/embed/public/embed/vcn6LE4P2hh6GzvtMbIAWxsXpDh6eSoNyAXdhfYaj9yDN6FJwOHIiz9ktqToj1HG?period=24h" height="400" frameBorder="0" scrolling="no"></iframe>
  
        </div>
      </Layout>
    </>
  )
}